Velruse Documentation — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- Velruse 1.1 documentation »

# Velruse Documentation

Velruse is a set of authentication routines that provide a unified way to have a website user authenticate to a variety of different identity providers and/or a variety of different authentication schemes.

It is similar in some ways to Janrain Engage with the exception of being open-source, locally installable, and easily pluggable for custom identity providers and authentication schemes.

You can run Velruse as a stand-alone service for use with your websites regardless of the language they’re written in. While Velruse itself is written in Python, since it can interact with your website purely via HTTP POST’s.

Velruse can:

- Normalize identity information from varying provider sources (OpenID, Google, Facebook, etc.) to Portable Contacts.
- Simplify complex authentication protocols by providing a simple consistent API
- Provide extension points for other authentication systems, write your own auth provider to handle CAS, LDAP, and use it with ease
- Integrate with most web applications regardless of the language used to write the website

Velruse aims to simplify authenticating a user. It provides auth provider‘s that handle authenticating to a variety of identity providers with multiple authentication schemes (LDAP, SAML, etc.). Eventually, Velruse will include widgets similar to RPXNow that allow one to customize a login/registration widget so that a website user can select a preferred identity provider to use to sign-in. In the mean-time, effort is focused on increasing the available auth provider‘s for the commonly used authentication schemes and identity providers (Facebook, Google, OpenID, etc). Unlike other authentication libraries for use with web applications, a website using Velruse for authentication does not have to be written in any particular language.

Contents:

- Architecture
  - Auth Providers
  - Provider HTML Examples
- Usage
  - As a Service
  - As a Pyramid Plugin
- Provider Documentation
  - Facebook - `velruse.providers.facebook`
  - Github - `velruse.providers.github`
  - Google
  - Windows Live - `velruse.providers.live`
  - Mail.ru - `velruse.providers.mailru`
  - OpenID - `velruse.providers.openid`
  - Twitter - `velruse.providers.twitter`
  - VK - `velruse.providers.vk`
  - Yahoo - `velruse.providers.yahoo`
  - Yandex - `velruse.providers.yandex`
- API Documentation
  - `velruse`
  - `velruse.app`
  - `velruse.utils`
- Changes
  - 1.1 (2013-06-27)
  - 1.0.3 (2012-10-11)
  - 1.0.2 (2012-10-11)
  - 1.0.1 (2012-08-30)
  - 1.0 (2012-08-14)
  - 0.3b3 (2012-08-06)
  - 0.3b2 (2012-08-06)
  - 0.3b1 (2012-08-03)
  - 0.20a1 (2011-05-25)
  - 0.1 (2010-04-30)

# Indices and tables

- Index
- Search Page
- Glossary

### Navigation

- index
- modules |
- next |
- Velruse 1.1 documentation »